==> request-tracker4_4.4.7+dfsg.orig-third-party-source.tar.gz: rt-4.4.7/devel/third-party/ckeditor-src/plugins/docprops/lang/sq.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'docprops', 'sq', {
	bgColor: 'Ngjyra e Prapavijës',
	bgFixed: 'Prapavijë pa zvarritje (fiks)',
	bgImage: 'URL e Fotografisë së Prapavijës',
	charset: 'Character Set Encoding', // MISSING
	charsetASCII: 'ASCII',
	charsetCE: 'Evropës Qendrore',
	charsetCR: 'Sllave',
	charsetCT: 'Kinezisht Tradicional (Big5)',
	charsetGR: 'Greke',
	charsetJP: 'Japoneze',
	charsetKR: 'Koreane',
	charsetOther: 'Other Character Set Encoding', // MISSING
	charsetTR: 'Turke',
	charsetUN: 'Unicode (UTF-8)',
	charsetWE: 'Evropiano Perëndimor',
	chooseColor: 'Përzgjidh',
	design: 'Dizajni',
	docTitle: 'Titulli i Faqes',
	docType: 'Document Type Heading', // MISSING
	docTypeOther: 'Koka e Llojit Tjetër të Dokumentit',
	label: 'Karakteristikat e Dokumentit',
	margin: 'Kufijtë e Faqes',
	marginBottom: 'Poshtë',
	marginLeft: 'Majtas',
	marginRight: 'Djathtas',
	marginTop: 'Lart',
	meta: 'Meta Tags', // MISSING
	metaAuthor: 'Autori',
	metaCopyright: 'Të drejtat e kopjimit',
	metaDescription: 'Përshkrimi i Dokumentit',
	metaKeywords: 'Fjalët kyçe të indeksimit të dokumentit (të ndarë me presje)',
	other: 'Tjera...',
	previewHtml: '<p>Ky është nje <strong>tekst shembull</strong>.  Ju jeni duke shfrytëzuar <a href="javascript:void(0)">CKEditor</a>.</p>',
	title: 'Karakteristikat e Dokumentit',
	txtColor: 'Ngjyra e Tekstit',
	xhtmlDec: 'Përfshij XHTML Deklarimet'
} );

==> request-tracker5_5.0.1+dfsg.orig-third-party-source.tar.gz: rt-5.0.1/devel/third-party/ckeditor-src/plugins/docprops/lang/sq.js <==
/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'docprops', 'sq', {
	bgColor: 'Ngjyra e Prapavijës',
	bgFixed: 'Prapavijë pa zvarritje (fiks)',
	bgImage: 'URL e Fotografisë së Prapavijës',
	charset: 'Kodimi i Setit të Karaktereve',
	charsetASCII: 'ASCII',
	charsetCE: 'Evropës Qendrore',
	charsetCR: 'Sllave',
	charsetCT: 'Kinezisht Tradicional (Big5)',
	charsetGR: 'Greke',
	charsetJP: 'Japoneze',
	charsetKR: 'Koreane',
	charsetOther: 'Kodimi i një Seti tjetër Karakteresh',
	charsetTR: 'Turke',
	charsetUN: 'Unicode (UTF-8)',
	charsetWE: 'Evropiano Perëndimor',
	chooseColor: 'Përzgjidh',
	design: 'Dizajni',
	docTitle: 'Titulli i Faqes',
	docType: 'Kokështrirja e Llojit të Dokumentit',
	docTypeOther: 'Koka e Llojit Tjetër të Dokumentit',
	label: 'Karakteristikat e Dokumentit',
	margin: 'Kufijtë e Faqes',
	marginBottom: 'Poshtë',
	marginLeft: 'Majtas',
	marginRight: 'Djathtas',
	marginTop: 'Lart',
	meta: 'Meta Etiketat',
	metaAuthor: 'Autori',
	metaCopyright: 'Të drejtat e kopjimit',
	metaDescription: 'Përshkrimi i Dokumentit',
	metaKeywords: 'Fjalët kyçe të indeksimit të dokumentit (të ndarë me presje)',
	other: 'Tjera...',
	previewHtml: '<p>Ky është nje <strong>tekst shembull</strong>.  Ju jeni duke shfrytëzuar <a href="javascript:void(0)">CKEditor</a>.</p>',
	title: 'Karakteristikat e Dokumentit',
	txtColor: 'Ngjyra e Tekstit',
	xhtmlDec: 'Përfshij XHTML Deklarimet'
} );
